.. _docs_and_tutorials:

*******************************
Quickstart Guides and Tutorials
*******************************

This section of the documentation contains both quickstart guides
and detailed usage-tutorials. If you are instead looking for 
a quick reference to the API of some class or function, try
looking in :ref:`complete_ref_full_api`.

Quickstart Guides
=================

.. toctree::
    :maxdepth: 1

    getting_started_overview

Downloading suite of galaxy catalogues
--------------------------------------

.. toctree::
    :maxdepth: 1

    quickstart_guides/guide_downloading_catls

    

    